@@ -5,6 +5,8 @@ import os
 import pickle
 import re
 import shutil
+from datetime import date
+from enum import Enum, EnumMeta
 from pathlib import Path
 from typing import (
     Any,
@@ -35,6 +37,7 @@ from vistautils.misc_utils import eval_in_context_of_modules
 from vistautils.preconditions import check_arg, check_isinstance
 from vistautils.range import Range
 
+import deprecation
 import yaml
 
 _logger = logging.getLogger(__name__)  # pylint:disable=invalid-name
@@ -46,6 +49,7 @@ class ParameterError(Exception):
 
 _ParamType = TypeVar("_ParamType")  # pylint:disable=invalid-name
 _U = TypeVar("_U")  # pylint:disable=invalid-name
+_EnumType = TypeVar("_EnumType", bound=Enum)
 
 
 @attrs(frozen=True, slots=True)
@@ -432,6 +436,33 @@ class Parameters:
         else:
             return None
 
+    def enum(
+        self,
+        param_name: str,
+        enum_class: Type[_EnumType],
+        *,
+        default: Optional[_EnumType] = None,
+    ) -> _EnumType:
+        """
+        Gets a valid enumeration member
+
+        `param_name` is interpreted as a valid member of the provided enumeration class.
+        If the member is not found within the larger class, then a ParameterError is raised.
+        """
+        enum_name = self.optional_string(param_name)
+        if enum_name in enum_class.__members__:
+            return enum_class[enum_name]  # type: ignore
+        elif enum_name is not None:
+            raise ParameterError(
+                f"For parameter {param_name}, {enum_name} could not be found in "
+                f"{list(enum_class.__members__)}"
+            )
+        elif default:
+            return default
+        else:
+            # Always raises error since param_name returned None on `optional_string()`
+            return self.string(param_name)  # type: ignore
+
     def string(
         self,
         param_name: str,
@@ -652,12 +683,14 @@ class Parameters:
         else:
             return None
 
+    @deprecation.deprecated(
+        deprecated_in="0.19.0",
+        removed_in=date(2020, 8, 10),
+        details="Deprecated, prefer `optional_floating_point` for more consistent naming.",
+    )
     def optional_float(
         self, name: str, valid_range: Optional[Range[float]] = None
     ) -> Optional[float]:
-        """
-        Deprecated, prefer `optional_floating_point` for more consistent naming.
-        """
         return self.optional_floating_point(name, valid_range)
 
     def boolean(self, name: str, *, default: Optional[bool] = None) -> bool:
@@ -685,10 +718,13 @@ class Parameters:
 
         return self.get_optional(name, bool, default=default)
 
+    @deprecation.deprecated(
+        deprecated_in="0.19.0",
+        removed_in=date(2020, 8, 10),
+        details="Deprecated. Prefer `boolean` with default as a parameter.",
+    )
     def optional_boolean_with_default(self, name: str, default_value: bool) -> bool:
         """
-        Deprecated. Prefer `boolean` with default as a parameter.
-
         Gets a boolean parameter if present; otherwise returns the provided default.
         """
         if default_value is not None:  # pragma: no cover
@@ -1312,10 +1348,12 @@ class Parameters:
         else:
             return ""
 
+    @deprecation.deprecated(
+        deprecated_in="0.19.0",
+        removed_in=date(2020, 8, 10),
+        details="Deprecated and may be removed. Prefer `Parameters.as_nested_dicts`.",
+    )
     def as_mapping(self) -> Mapping[str, Any]:
-        """
-        Deprecated and may be removed. Prefer `Parameters.as_nested_dicts`.
-        """
         return self._data
 
     def _warn_about_default(self) -> None:
